@@ -15,27 +15,27 @@ public:
 	static DirectorExtension &Instance();
 
 	// Implement the Extension interface
-	virtual bool Initialise(ExtensionAPI *host_);
-	virtual bool Finalise();
-	virtual bool Clear();
-	virtual bool Load(const char *filename);
+	bool Initialise(ExtensionAPI *host_) override;
+	bool Finalise() override;
+	bool Clear() override;
+	bool Load(const char *filename) override;
 
-	virtual bool OnOpen(const char *path);
-	virtual bool OnSwitchFile(const char *path);
-	virtual bool OnSave(const char *path);
-	virtual bool OnChar(char ch);
-	virtual bool OnExecute(const char *cmd);
-	virtual bool OnSavePointReached();
-	virtual bool OnSavePointLeft();
-	virtual bool OnStyle(unsigned int startPos, int lengthDoc, int initStyle, StyleWriter *styler);
-	virtual bool OnDoubleClick();
-	virtual bool OnUpdateUI();
-	virtual bool OnMarginClick();
-	virtual bool OnMacro(const char *command, const char *params);
+	bool OnOpen(const char *path) override;
+	bool OnSwitchFile(const char *path) override;
+	bool OnSave(const char *path) override;
+	bool OnChar(char ch) override;
+	bool OnExecute(const char *cmd) override;
+	bool OnSavePointReached() override;
+	bool OnSavePointLeft() override;
+	bool OnStyle(unsigned int startPos, int lengthDoc, int initStyle, StyleWriter *styler) override;
+	bool OnDoubleClick() override;
+	bool OnUpdateUI() override;
+	bool OnMarginClick() override;
+	bool OnMacro(const char *command, const char *params) override;
 
-	virtual bool SendProperty(const char *prop);
-	virtual bool OnClose(const char *path);
-	virtual bool NeedsOnClose();
+	bool SendProperty(const char *prop) override;
+	bool OnClose(const char *path) override;
+	bool NeedsOnClose() override;
 
 	// Allow messages through to extension
 	void HandleStringMessage(const char *message);
