@@ -53,6 +53,13 @@ gui_string StringFromLongLong(long long i) {
 	return gui_string();
 }
 
+std::string LowerCaseUTF8(std::string_view sv) {
+	gchar *lower = g_utf8_strdown(sv.data(), sv.length());
+	const std::string sLower(lower);
+	g_free(lower);
+	return sLower;
+}
+
 static GtkWidget *PWidget(WindowID wid) {
 	return static_cast<GtkWidget *>(wid);
 }
@@ -181,7 +188,7 @@ double ElapsedTime::Duration(bool reset) {
 	return result;
 }
 
-sptr_t ScintillaWindow::Send(unsigned int msg, uptr_t wParam, sptr_t lParam) {
+sptr_t ScintillaPrimitive::Send(unsigned int msg, uptr_t wParam, sptr_t lParam) {
 	return scintilla_send_message(SCINTILLA(GetID()), msg, wParam, lParam);
 }
 
