@@ -80,7 +80,7 @@ private:
 public:
 	WCheckDraw();
 	~WCheckDraw();
-	void Create(const char **xpmImage, GUI::gui_string toolTip, GtkStyle *pStyle_);
+	void Create(const char **xpmImage, const GUI::gui_string &toolTip, GtkStyle *pStyle_);
 	bool Active();
 	void SetActive(bool active);
 	void Toggle();
@@ -104,7 +104,7 @@ public:
 		int xpadding=5, int ypadding=5);
 	void Label(GtkWidget *child);
 	void PackInto(GtkBox *box, gboolean expand=TRUE);
-	void Resize(int rows, int columns);
+	void Resize(int rows_, int columns_);
 	void NextLine();
 };
 
