@@ -9,10 +9,6 @@
 
 class WatcherHelper;
 
-#ifdef SCI_NAMESPACE
-namespace Scintilla {
-#endif
-
 #ifndef EXPORT_IMPORT_API
 #ifdef WIN32
 #ifdef MAKING_LIBRARY
@@ -88,12 +84,8 @@ signals:
     void style_needed(int pos);
     void lexer_changed();
     void error_occurred(int status);
-    
+
     friend class ::WatcherHelper;
 };
 
-#ifdef SCI_NAMESPACE
-}
-#endif
-
 #endif // SCINTILLADOCUMENT_H
