@@ -380,10 +380,12 @@ void ScintillaQt::NotifyChange()
 
 void ScintillaQt::NotifyFocus(bool focus)
 {
-	emit command(
-			Platform::LongFromTwoShorts
-					(GetCtrlID(), focus ? SCEN_SETFOCUS : SCEN_KILLFOCUS),
-			reinterpret_cast<sptr_t>(wMain.GetID()));
+	if (commandEvents) {
+		emit command(
+				Platform::LongFromTwoShorts
+						(GetCtrlID(), focus ? SCEN_SETFOCUS : SCEN_KILLFOCUS),
+				reinterpret_cast<sptr_t>(wMain.GetID()));
+	}
 
 	Editor::NotifyFocus(focus);
 }
@@ -699,9 +701,9 @@ void ScintillaQt::PartialPaint(const PRectangle &rect)
 	PRectangle rcClient = GetClientRectangle();
 	paintingAllText = rcPaint.Contains(rcClient);
 
-	AutoSurface surface(this);
-	Paint(surface, rcPaint);
-	surface->Release();
+	AutoSurface surfacePaint(this);
+	Paint(surfacePaint, rcPaint);
+	surfacePaint->Release();
 
 	if (paintState == paintAbandoned) {
 		// FIXME: Failure to paint the requested rectangle in each
