@@ -30,7 +30,7 @@
 # On Fedora 17, qmake is called qmake-qt4 so sepbuild.py should probe for correct name.
 # There are also problems with clang failing in the g++ 4.7 headers.
 
-# Run commands in parallel up to number of processors 
+# Run commands in parallel up to number of processors
 JOBS="-j $(getconf _NPROCESSORS_ONLN)"
 
 cd ../..
@@ -70,7 +70,15 @@ cd ../..
 # Target 3: Qt builds
 # Requires Qt development libraries and qmake to be installed
 
-QMAKENAME=$(basename `which qmake-qt5 || which qmake-qt4 || which qmake`)
+# Find best available qmake
+QMAKENAME=""
+if hash qmake-qt5 2>/dev/null; then
+	QMAKENAME="qmake-qt5"
+elif hash qmake 2>/dev/null; then
+	QMAKENAME="qmake -qt=5"
+elif hash qmake-qt4 2>/dev/null; then
+	QMAKENAME="qmake-qt4"
+fi
 
 cd scintilla/qt
 cd ScintillaEditBase
@@ -144,4 +152,4 @@ cd ../..
 # Target 7: cppcheck static checker
 # Disabled as there are false warnings and some different style choices
 cppcheck --enable=all --max-configs=100 --suppressions-list=scintilla/cppcheck.suppress -I scintilla/src -I scintilla/include -I scintilla/lexlib -I scintilla/qt/ScintillaEditBase --template=gcc --quiet scintilla
-cppcheck --enable=all --max-configs=100 -I scite/src -I scintilla/include -I scite/lua/include -Ulua_assert -DPATH_MAX=260 --template=gcc --quiet scite
+cppcheck --enable=all --max-configs=100 --suppressions-list=scite/cppcheck.suppress -I scite/src -I scintilla/include -I scite/lua/include -Ulua_assert -DPATH_MAX=260 --template=gcc --quiet scite
