@@ -229,6 +229,7 @@ protected:	// ScintillaBase subclass needs access to much of Editor
 	bool needIdleStyling;
 
 	int modEventMask;
+	bool commandEvents;
 
 	SelectionText drag;
 
@@ -249,6 +250,7 @@ protected:	// ScintillaBase subclass needs access to much of Editor
 
 	// Wrapping support
 	WrapPending wrapPending;
+	ActionDuration durationWrapOneLine;
 
 	bool convertPastes;
 
