@@ -582,7 +582,7 @@ bool SciTEBase::Open(const FilePath &file, OpenFlags of) {
 		std::string propertiesText = CommandExecute(GUI::StringFromUTF8(discoveryScript).c_str(),
 			absPath.Directory().AsInternal());
 		if (propertiesText.size()) {
-			propsDiscovered.ReadFromMemory(propertiesText.c_str(), propertiesText.size(), absPath.Directory(), filter, NULL, 0);
+			propsDiscovered.ReadFromMemory(propertiesText.c_str(), propertiesText.size(), absPath.Directory(), filter, nullptr, 0);
 		}
 	}
 	CurrentBuffer()->props = propsDiscovered;
@@ -706,7 +706,7 @@ bool SciTEBase::OpenSelected() {
 	if (!FilePath(selFN).IsAbsolute()) {
 		path = filePath.Directory();
 		// If not there, look in openpath
-		if (!Exists(path.AsInternal(), selFN.c_str(), NULL)) {
+		if (!Exists(path.AsInternal(), selFN.c_str(), nullptr)) {
 			GUI::gui_string openPath = GUI::StringFromUTF8(props.GetNewExpandString(
 			            "openpath.", fileNameForExtension.c_str()));
 			while (openPath.length()) {
@@ -718,7 +718,7 @@ bool SciTEBase::OpenSelected() {
 				} else {
 					openPath.erase();
 				}
-				if (Exists(tryPath.c_str(), selFN.c_str(), NULL)) {
+				if (Exists(tryPath.c_str(), selFN.c_str(), nullptr)) {
 					path.Set(tryPath.c_str());
 					break;
 				}
