@@ -542,7 +542,7 @@ static const char *propertiesToForward[] = {
 
 //--Autogenerated -- end of automatically generated section
 
-	0,
+	nullptr,
 };
 
 /* XPM */
