@@ -5,12 +5,11 @@
 // Copyright 2010 by Neil Hodgson <neilh@scintilla.org>
 // The License.txt file describes the conditions under which this software may be distributed.
 
-#include <string.h>
-#include <stdio.h>
+#include <cstring>
+#include <cstdio>
 
 #include <string>
 #include <vector>
-#include <sstream>
 #include <algorithm>
 #include <functional>
 
@@ -19,19 +18,17 @@
 #include "GUI.h"
 #include "StringHelpers.h"
 
-bool StartsWith(GUI::gui_string const &s, GUI::gui_string const &start) {
+bool StartsWith(std::wstring_view s, std::wstring_view start) {
 	return (s.size() >= start.size()) &&
 		(std::equal(s.begin(), s.begin() + start.size(), start.begin()));
 }
 
-bool StartsWith(std::string const &s, const char *start) {
-	const size_t startSize = strlen(start);
-	std::string sStart(start);
-	return (s.size() >= startSize) &&
-		(std::equal(s.begin(), s.begin() + startSize, sStart.begin()));
+bool StartsWith(std::string_view s, std::string_view start) {
+	return (s.size() >= start.size()) &&
+		(std::equal(s.begin(), s.begin() + start.size(), start.begin()));
 }
 
-bool EndsWith(GUI::gui_string const &s, GUI::gui_string const &end) {
+bool EndsWith(std::wstring_view s, std::wstring_view end) {
 	return (s.size() >= end.size()) &&
 		(std::equal(s.begin() + s.size() - end.size(), s.end(), end.begin()));
 }
@@ -42,8 +39,8 @@ bool Contains(std::string const &s, char ch) {
 
 int Substitute(std::wstring &s, const std::wstring &sFind, const std::wstring &sReplace) {
 	int c = 0;
-	size_t lenFind = sFind.size();
-	size_t lenReplace = sReplace.size();
+	const size_t lenFind = sFind.size();
+	const size_t lenReplace = sReplace.size();
 	size_t posFound = s.find(sFind);
 	while (posFound != std::wstring::npos) {
 		s.replace(posFound, lenFind, sReplace);
@@ -55,8 +52,8 @@ int Substitute(std::wstring &s, const std::wstring &sFind, const std::wstring &s
 
 int Substitute(std::string &s, const std::string &sFind, const std::string &sReplace) {
 	int c = 0;
-	size_t lenFind = sFind.size();
-	size_t lenReplace = sReplace.size();
+	const size_t lenFind = sFind.size();
+	const size_t lenReplace = sReplace.size();
 	size_t posFound = s.find(sFind);
 	while (posFound != std::string::npos) {
 		s.replace(posFound, lenFind, sReplace);
@@ -67,7 +64,7 @@ int Substitute(std::string &s, const std::string &sFind, const std::string &sRep
 }
 
 bool RemoveStringOnce(std::string &s, const char *marker) {
-	size_t modText = s.find(marker);
+	const size_t modText = s.find(marker);
 	if (modText != std::string::npos) {
 		s.erase(modText, strlen(marker));
 		return true;
@@ -76,15 +73,11 @@ bool RemoveStringOnce(std::string &s, const char *marker) {
 }
 
 std::string StdStringFromInteger(int i) {
-	char number[32];
-	sprintf(number, "%0d", i);
-	return std::string(number);
+	return std::to_string(i);
 }
 
 std::string StdStringFromSizeT(size_t i) {
-	std::ostringstream strstrm;
-	strstrm << i;
-	return strstrm.str();
+	return std::to_string(i);
 }
 
 std::string StdStringFromDouble(double d, int precision) {
@@ -137,7 +130,33 @@ bool isprefix(const char *target, const char *prefix) {
 		return true;
 }
 
-unsigned int UTF32Character(const unsigned char *utf8) {
+std::u32string UTF32FromUTF8(std::string_view s) {
+	std::u32string ret;
+	while (!s.empty()) {
+		const unsigned char uc = static_cast<unsigned char>(s.front());
+		size_t lenChar = 1;
+		if (uc >= 0x80 + 0x40 + 0x20 + 0x10) {
+			lenChar = 4;
+		} else if (uc >= 0x80 + 0x40 + 0x20) {
+			lenChar = 3;
+		} else if (uc >= 0x80 + 0x40) {
+			lenChar = 2;
+		}
+		if (lenChar > s.length()) {
+			// Character fragment
+			for (size_t i = 0; i < s.length(); i++) {
+				ret.push_back(static_cast<unsigned char>(s[i]));
+			}
+			break;
+		}
+		const char32_t ch32 = UTF32Character(s.data());
+		ret.push_back(ch32);
+		s.remove_prefix(lenChar);
+	}
+	return ret;
+}
+
+unsigned int UTF32Character(const char *utf8) {
 	unsigned char ch = utf8[0];
 	unsigned int u32Char;
 	if (ch < 0x80) {
@@ -169,7 +188,7 @@ unsigned int UTF32Character(const unsigned char *utf8) {
  */
 std::string Slash(const std::string &s, bool quoteQuotes) {
 	std::string oRet;
-	for (char ch : s) {
+	for (const char ch : s) {
 		if (ch == '\a') {
 			oRet.append("\\a");
 		} else if (ch == '\b') {
@@ -294,7 +313,7 @@ unsigned int UnSlash(char *s) {
 
 std::string UnSlashString(const char *s) {
 	std::string sCopy(s, strlen(s) + 1);
-	unsigned int len = UnSlash(&sCopy[0]);
+	const unsigned int len = UnSlash(&sCopy[0]);
 	return sCopy.substr(0, len);
 }
 
@@ -322,6 +341,6 @@ static unsigned int UnSlashLowOctal(char *s) {
 
 std::string UnSlashLowOctalString(const char *s) {
 	std::string sCopy(s, strlen(s) + 1);
-	unsigned int len = UnSlashLowOctal(&sCopy[0]);
+	const unsigned int len = UnSlashLowOctal(&sCopy[0]);
 	return sCopy.substr(0, len);
 }
