@@ -5,9 +5,9 @@
 // Copyright 2010 by Neil Hodgson <neilh@scintilla.org>
 // The License.txt file describes the conditions under which this software may be distributed.
 
-bool StartsWith(GUI::gui_string const &s, GUI::gui_string const &start);
-bool StartsWith(std::string const &s, const char *start);
-bool EndsWith(GUI::gui_string const &s, GUI::gui_string const &end);
+bool StartsWith(std::wstring_view s, std::wstring_view start);
+bool StartsWith(std::string_view s, std::string_view start);
+bool EndsWith(std::wstring_view s, std::wstring_view end);
 bool Contains(std::string const &s, char ch);
 
 // Substitute is duplicated instead of templated as it was ambiguous when implemented as a template.
@@ -36,6 +36,10 @@ inline char MakeUpperCase(char ch) {
 		return static_cast<char>(ch - 'a' + 'A');
 }
 
+inline bool IsASCII(int ch) {
+	return (ch >= 0) && (ch < 0x80);
+}
+
 // StringSplit can be expanded over std::string or GUI::gui_string
 template <typename T>
 std::vector<T> StringSplit(const T &text, int separator) {
@@ -72,9 +76,13 @@ void StringCopy(T (&dest)[count], const T* source) {
 int CompareNoCase(const char *a, const char *b);
 bool EqualCaseInsensitive(const char *a, const char *b);
 bool isprefix(const char *target, const char *prefix);
-unsigned int UTF32Character(const unsigned char *utf8);
 
-char *Slash(const char *s, bool quoteQuotes);
+constexpr const char *UTF8BOM = "\xef\xbb\xbf";
+
+std::u32string UTF32FromUTF8(std::string_view s);
+unsigned int UTF32Character(const char *utf8);
+
+std::string Slash(const std::string &s, bool quoteQuotes);
 unsigned int UnSlash(char *s);
 std::string UnSlashString(const char *s);
 std::string UnSlashLowOctalString(const char *s);
