@@ -150,6 +150,8 @@ class XiteWin():
 
 		self.appName = "xite"
 
+		self.large = "-large" in sys.argv
+
 		self.cmds = {}
 		self.windowName = "XiteWindow"
 		self.wfunc = WFUNC(self.WndProc)
@@ -158,7 +160,7 @@ class XiteWin():
 			WS_VISIBLE | WS_OVERLAPPEDWINDOW | WS_CLIPCHILDREN, \
 			0, 0, 500, 700, 0, 0, hinst, 0)
 
-		args = sys.argv[1:]
+		args = [a for a in sys.argv[1:] if not a.startswith("-")]
 		self.SetMenus()
 		if args:
 			self.GrabFile(args[0])
@@ -198,6 +200,9 @@ class XiteWin():
 		sciptr = c_char_p(user32.SendMessageW(self.sciHwnd,
 			int(self.face.features["GetDirectPointer"]["Value"], 0), 0,0))
 		self.ed = ScintillaCallable.ScintillaCallable(self.face, scifn, sciptr)
+		if self.large:
+			doc = self.ed.CreateDocument(10, 0x100)
+			self.ed.SetDocPointer(0, doc)
 
 		self.FocusOnEditor()
 
