@@ -8,21 +8,19 @@
 #ifndef PLATWIN_H
 #define PLATWIN_H
 
-#ifdef SCI_NAMESPACE
 namespace Scintilla {
-#endif
 
 extern void Platform_Initialise(void *hInstance);
 extern void Platform_Finalise(bool fromDllMain);
 
+RECT RectFromPRectangle(PRectangle prc) noexcept;
+
 #if defined(USE_D2D)
 extern bool LoadD2D();
 extern ID2D1Factory *pD2DFactory;
 extern IDWriteFactory *pIDWriteFactory;
 #endif
 
-#ifdef SCI_NAMESPACE
 }
-#endif
 
 #endif
