@@ -193,7 +193,7 @@ void SciTEWin::Notify(SCNotification *notification) {
 	case TTN_GETDISPINFO:
 		// Ask for tooltip text
 		{
-			const GUI::gui_char *ttext = 0;
+			const GUI::gui_char *ttext = nullptr;
 			NMTTDISPINFOW *pDispInfo = reinterpret_cast<NMTTDISPINFOW *>(notification);
 			// Toolbar tooltips
 			switch (notification->nmhdr.idFrom) {
@@ -642,7 +642,7 @@ static LRESULT PASCAL TabWndProc(HWND hWnd, UINT iMessage, WPARAM wParam, LPARAM
 	static BOOL st_bDragBegin = FALSE;
 	static int st_iDraggingTab = -1;
 	static int st_iLastClickTab = -1;
-	static HWND st_hwndLastFocus = NULL;
+	static HWND st_hwndLastFocus {};
 
 	switch (iMessage) {
 
@@ -675,7 +675,7 @@ static LRESULT PASCAL TabWndProc(HWND hWnd, UINT iMessage, WPARAM wParam, LPARAM
 	case WM_LBUTTONUP: {
 			st_iLastClickTab = -1;
 			if (st_bDragBegin == TRUE) {
-				if (st_hwndLastFocus != NULL) ::SetFocus(st_hwndLastFocus);
+				if (st_hwndLastFocus) ::SetFocus(st_hwndLastFocus);
 				::ReleaseCapture();
 				::SetCursor(::LoadCursor(NULL, IDC_ARROW));
 				st_bDragBegin = FALSE;
@@ -695,7 +695,7 @@ static LRESULT PASCAL TabWndProc(HWND hWnd, UINT iMessage, WPARAM wParam, LPARAM
 	case WM_KEYDOWN: {
 			if (wParam == VK_ESCAPE) {
 				if (st_bDragBegin == TRUE) {
-					if (st_hwndLastFocus != NULL) ::SetFocus(st_hwndLastFocus);
+					if (st_hwndLastFocus) ::SetFocus(st_hwndLastFocus);
 					::ReleaseCapture();
 					::SetCursor(::LoadCursor(NULL, IDC_ARROW));
 					st_bDragBegin = FALSE;
@@ -831,6 +831,7 @@ void SciTEWin::Creation() {
 		exit(FALSE);
 	wEditor.Show();
 	wEditor.Call(SCI_USEPOPUP, 0);
+	wEditor.Call(SCI_SETCOMMANDEVENTS, 0);
 	WindowSetFocus(wEditor);
 
 	wOutput.SetScintilla(::CreateWindowEx(
@@ -847,6 +848,7 @@ void SciTEWin::Creation() {
 	if (!wOutput.CanCall())
 		exit(FALSE);
 	wOutput.Show();
+	wOutput.Call(SCI_SETCOMMANDEVENTS, 0);
 	// No selection margin on output window
 	wOutput.Call(SCI_SETMARGINWIDTHN, 1, 0);
 	//wOutput.Call(SCI_SETCARETPERIOD, 0);
