@@ -14,12 +14,14 @@
 class WinMutex : public Mutex {
 private:
 	CRITICAL_SECTION cs;
-	virtual void Lock() { ::EnterCriticalSection(&cs); }
-	virtual void Unlock() { ::LeaveCriticalSection(&cs); }
+	void Lock() override { ::EnterCriticalSection(&cs); }
+	void Unlock() override { ::LeaveCriticalSection(&cs); }
 	WinMutex() { ::InitializeCriticalSection(&cs); }
 	// Deleted so WinMutex objects can not be copied.
 	WinMutex(const WinMutex &) = delete;
+	WinMutex(WinMutex &&) = delete;
 	void operator=(const WinMutex &) = delete;
+	void operator=(WinMutex &&) = delete;
 	virtual ~WinMutex() { ::DeleteCriticalSection(&cs); }
 	friend class Mutex;
 };
